@@ -10,8 +10,10 @@ ALLOWED_CLASSIFIERS = [
     'OneClassSVM',
     'RVC',
     'SEFR',
-    'DecisionTree',
-    'RandomForest',
+    'DecisionTreeClassifier',
+    'DecisionTreeRegressor',
+    'RandomForestClassifier',
+    'RandomForestRegressor',
     'GaussianNB',
     'LogisticRegression',
     'PCA',
